Release notes
-------------
### Version v21.4.9

- Added support Gentoo style versions. 

### Version v21.4.8

- More package types supported.
- Version classes are hashable and frozen now

### Version v21.4.6

- Initial Release

